@@ -1,26 +1,25 @@
-'''
-This file is a part of Arjuna
-Copyright 2015-2020 Rahul Verma
+# This file is a part of Arjuna
+# Copyright 2015-2020 Rahul Verma
 
-Website: www.RahulVerma.net
+# Website: www.RahulVerma.net
 
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 
-  http://www.apache.org/licenses/LICENSE-2.0
+#   http://www.apache.org/licenses/LICENSE-2.0
 
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
-'''
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 import platform
 import os
 import uuid
 from enum import Enum
+from arjuna.tpi.enums import *
 from arjuna.core.enums import *
 from arjuna.core.types.descriptors import *
 
@@ -69,7 +68,7 @@ class Config:
     def processor(self, processor):
         self.__processor = processor
 
-    def as_json_dict(self):
+    def items(self):
         return {
             "arjunaOptions": self.arjuna_config.as_json_dict(),
             "userOptions": self.user_config.as_json_dict()
@@ -197,6 +196,9 @@ class AbstractConfig:
                 ArjunaCore.console.marker(100)
         ArjunaCore.console.marker(100)
 
+    def items(self):
+        return self.__config_dict.items()
+
 
 class UserConfig(AbstractConfig):
 
@@ -242,9 +244,6 @@ class ArjunaConfig(AbstractConfig):
     def get_gui_automator_name(self):
         return self._config_dict[ArjunaOption.GUIAUTO_NAME]
 
-    def get_guiauto_actor_mode(self):
-        return self._config_dict[ArjunaOption.SETU_GUIAUTO_ACTOR_MODE]
-
     def get_guiauto_context(self):
         return self._config_dict[ArjunaOption.GUIAUTO_CONTEXT]
 
