@@ -1,34 +1,24 @@
-'''
-This file is a part of Arjuna
-Copyright 2015-2020 Rahul Verma
+# This file is a part of Arjuna
+# Copyright 2015-2020 Rahul Verma
 
-Website: www.RahulVerma.net
+# Website: www.RahulVerma.net
 
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 
-  http://www.apache.org/licenses/LICENSE-2.0
+#   http://www.apache.org/licenses/LICENSE-2.0
 
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
-'''
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 from arjuna import ArjunaOption
 
 from .config import Config
-from arjuna.core.adv.types import CIStringDict
-
-# class ArjunaOptionMap(AbstractValueMap):
-
-#     def __init__(self, object_map=None, headers=None, objects=None):
-#         super().__init__(object_map, headers, objects)
-
-#     def _format_key_as_str(self, key):
-#         return str(key)
+from arjuna.tpi.helper.arjtype import CIStringDict
 
 class ConfigContainer:
 
@@ -60,8 +50,6 @@ class ConfigContainer:
         try:
             self.set_arjuna_option(option, obj)
         except Exception as e:
-            import traceback
-            traceback.print_exc()
             self.set_user_option(option, obj)
         return self
 
