@@ -1,34 +1,33 @@
-'''
-This file is a part of Arjuna
-Copyright 2015-2020 Rahul Verma
+# This file is a part of Arjuna
+# Copyright 2015-2020 Rahul Verma
 
-Website: www.RahulVerma.net
+# Website: www.RahulVerma.net
 
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 
-  http://www.apache.org/licenses/LICENSE-2.0
+#   http://www.apache.org/licenses/LICENSE-2.0
 
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
-'''
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 import inspect
 import os
 import re
 import sys
 from urllib3.util import parse_url
+from arjuna.tpi.enums import *
 from arjuna.core.enums import *
 from arjuna.core.types.constants import *
 
 class Validator:
     VNREGEX = r'^([a-zA-Z][a-zA-Z_0-9]{2,50})$'
     VNREGEX_TEXT = '''
-    An Arjuna name must be a string of length 3-50 starting with a letter, followed by letters, digits or _ (underscore).
+    Name must be a string of length 3-50 starting with a letter, followed by letters, digits or _ (underscore).
     '''
 
     @classmethod
@@ -153,6 +152,29 @@ class Validator:
                 cls.raise_exc(input)
         return input
 
+    @classmethod
+    def allowed_log_contexts(cls, input):
+        if type(input) is str:
+            input = [i.strip().lower() for i in input.split(",")]
+            input = set(input)
+        elif type(input) in {set, list, tuple}:
+            input = set([i.lower() for i in input])
+        else:
+            cls.raise_exc(input)    
+
+        input.add("default")
+        return input 
+
+    @classmethod
+    def str_or_strlist(cls, input):
+        if type(input) is str:
+            input = [i.strip().lower() for  i in input.split(",")]
+        elif type(input) in {set, list, tuple}:
+            input = [i.lower() for i in input if i not in input]
+        else:
+            cls.raise_exc(input)
+        return list(dict.fromkeys(input)) 
+
     @classmethod
     def actor_mode(cls, input):
         try:
@@ -230,9 +252,9 @@ class Validator:
         return input
 
     @classmethod
-    def arjuna_name(cls, input):
+    def name(cls, input):
         if not re.match(cls.VNREGEX, input):
-            print('Invalid Arjuna name provided.', file=sys.stderr)
+            print('Invalid name provided.', file=sys.stderr)
             print(cls.VNREGEX_TEXT, file=sys.stderr)
             cls.raise_exc(input, msg=cls.VNREGEX_TEXT)
         return input
