@@ -1,21 +1,19 @@
-'''
-This file is a part of Arjuna
-Copyright 2015-2020 Rahul Verma
+# This file is a part of Arjuna
+# Copyright 2015-2020 Rahul Verma
 
-Website: www.RahulVerma.net
+# Website: www.RahulVerma.net
 
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 
-  http://www.apache.org/licenses/LICENSE-2.0
+#   http://www.apache.org/licenses/LICENSE-2.0
 
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
-'''
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 import os
 from .source import *
@@ -40,30 +38,23 @@ def get_data_file_path(data_dir, fpath):
                 raise Exception("File does not exist: {}".format(fpath))
         return fpath
 
-def create_file_data_source(file_path, record_format="MAP", delimiter="\t"):
+def create_file_data_source(file_path, *, context, delimiter="\t"):
     from arjuna import Arjuna, ArjunaOption
     data_dir = Arjuna.get_config().value(ArjunaOption.DATA_SRC_DIR)
     file_path = get_data_file_path(data_dir, file_path)
     ds = None
     ext = file_path.lower()
-    rformat = record_format.upper()
     if ext.endswith(".csv") or ext.endswith(".txt"):
-        if rformat == "LIST":
-            ds = DsvFileListDataSource(file_path, delimiter)
-        else:
-            ds = DsvFileMapDataSource(file_path, delimiter)
+        ds = DsvFileMapDataSource(file_path, delimiter, context=context)
     elif ext.endswith(".xls"):
-        if rformat == "LIST":
-            ds = ExcelFileListDataSource(file_path)
-        else:
-            ds = ExcelFileMapDataSource(file_path)
+        ds = ExcelFileMapDataSource(file_path, context=context)
     elif ext.endswith(".ini"):
-        ds = IniFileDataSource(file_path)
+        ds = IniFileDataSource(file_path, context=context)
     else:
         raise Exception("This is not a default file format supported as a data source: " + path)
     return ds
 
-from arjuna.core.adv.types import CIStringDict
+from arjuna.tpi.helper.arjtype import CIStringDict
 
 class DataReferences:
 
@@ -90,7 +81,7 @@ class DataReference:
 
     @classmethod
     def load_all(cls, ref_config):
-        from arjuna.core.enums import ArjunaOption
+        from arjuna.tpi.enums import ArjunaOption
         refs = DataReferences()
         column_data_ref_dir = ref_config.value(ArjunaOption.DATA_REF_COLUMN_DIR)
         for fname in os.listdir(column_data_ref_dir):
