@@ -1,27 +1,25 @@
-'''
-This file is a part of Arjuna
-Copyright 2015-2020 Rahul Verma
+# This file is a part of Arjuna
+# Copyright 2015-2020 Rahul Verma
 
-Website: www.RahulVerma.net
+# Website: www.RahulVerma.net
 
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 
-  http://www.apache.org/licenses/LICENSE-2.0
+#   http://www.apache.org/licenses/LICENSE-2.0
 
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
-'''
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 import abc
 
 from arjuna.core.reader.excel import *
-from .record import *
-from arjuna.core.adv.types import CIStringDict
+from arjuna.tpi.engine.data.record import *
+from arjuna.tpi.helper.arjtype import CIStringDict
 
 class ContextualDataReference(metaclass=abc.ABCMeta):
 
@@ -87,7 +85,7 @@ class ExcelRowDataReference(__ExcelDataReference):
             except StopIteration:
                 break
             else:
-                self.map[data_record[0].lower()] = DataRecord(**dict(zip(names, data_record[1:])))
+                self.map[data_record[0].lower()] = DataRecord(context="Ref", **dict(zip(names, data_record[1:])))
         self.reader.close()
 
 
@@ -110,7 +108,7 @@ class ExcelColumnDataReference(__ExcelDataReference):
                     cmap[context][name] = data_record[index+1]
         self.reader.close()
         for context, kv in cmap.items():
-            self.map[context.lower()] = DataRecord(**kv)
+            self.map[context.lower()] = DataRecord(context="Ref", **kv)
 
 def R(query, *, bucket=None, context=None):
     from arjuna import Arjuna, ArjunaOption
