@@ -1,23 +1,22 @@
-'''
-This file is a part of Arjuna
-Copyright 2015-2020 Rahul Verma
+# This file is a part of Arjuna
+# Copyright 2015-2020 Rahul Verma
 
-Website: www.RahulVerma.net
+# Website: www.RahulVerma.net
 
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 
-  http://www.apache.org/licenses/LICENSE-2.0
+#   http://www.apache.org/licenses/LICENSE-2.0
 
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
-'''
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
-from arjuna.core.enums import ArjunaOption, DesktopOS
+from arjuna.tpi.enums import *
+from arjuna.core.enums import *
 import pprint
 from enum import Enum, auto
 
@@ -29,9 +28,9 @@ class SetuActorDriverConfigOption(Enum):
     BROWSER_NAME = auto()
     BROWSER_HEADLESS = auto()
     BROWSER_BIN_PATH = auto()
-    BROWSER_PROXY_ON = auto()
-    BROWSER_PROXY_HOST = auto()
-    BROWSER_PROXY_PORT = auto()
+    # BROWSER_PROXY_ON = auto()
+    # BROWSER_PROXY_HOST = auto()
+    # BROWSER_PROXY_PORT = auto()
     MOBILE_OS_NAME = auto()
 
     # Selenium
