@@ -1,24 +1,23 @@
-'''
-This file is a part of Arjuna
-Copyright 2015-2020 Rahul Verma
+# This file is a part of Arjuna
+# Copyright 2015-2020 Rahul Verma
 
-Website: www.RahulVerma.net
+# Website: www.RahulVerma.net
 
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 
-  http://www.apache.org/licenses/LICENSE-2.0
+#   http://www.apache.org/licenses/LICENSE-2.0
 
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
-'''
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 from selenium.webdriver.common.by import By
 from selenium.common.exceptions import NoSuchElementException
+from arjuna.tpi.exceptions import *
 from arjuna.core.exceptions import *
 
 class ElementFinder:
@@ -40,12 +39,12 @@ class ElementFinder:
         try:
             return container.find_element(cls.BY_MAP[byType.upper()], byValue)
         except Exception as e:
-            raise GuiElementNotFoundError("By.{}={}".format(byType, byValue))
+            raise GuiWidgetNotFoundError("By.{}={}".format(byType, byValue))
 
 
     @classmethod
     def find_elements(cls, container, byType, byValue):
         elements = container.find_elements(cls.BY_MAP[byType.upper()], byValue)
         if len(elements) == 0:
-            raise GuiElementNotFoundError("By.{}={}".format(byType, byValue))
+            raise GuiWidgetNotFoundError("By.{}={}".format(byType, byValue))
         return elements
