@@ -1,26 +1,25 @@
-'''
-This file is a part of Arjuna
-Copyright 2015-2020 Rahul Verma
+# This file is a part of Arjuna
+# Copyright 2015-2020 Rahul Verma
 
-Website: www.RahulVerma.net
+# Website: www.RahulVerma.net
 
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 
-  http://www.apache.org/licenses/LICENSE-2.0
+#   http://www.apache.org/licenses/LICENSE-2.0
 
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
-'''
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 
 from arjuna.interact.gui.dispatcher.driver.element_commands import DriverElementCommands
 from arjuna.interact.gui.dispatcher.driver.element_finder import ElementFinder
 from arjuna.interact.gui.dispatcher.driver.melement import MultiElement
+from arjuna.tpi.exceptions import *
 from arjuna.core.exceptions import *
 
 class SeleniumDriverElementDispatcher:
@@ -61,7 +60,7 @@ class SeleniumDriverElementDispatcher:
         try:
             DriverElementCommands.click(self.driver_element)
         except Exception as e:
-            raise GuiElementNotReadyError(str(e))
+            raise GuiWidgetNotReadyError(str(e))
 
     def hover(self):
         self.__driver_dispatcher.hover_on_element(self)
