@@ -1,21 +1,19 @@
-'''
-This file is a part of Arjuna
-Copyright 2015-2020 Rahul Verma
+# This file is a part of Arjuna
+# Copyright 2015-2020 Rahul Verma
 
-Website: www.RahulVerma.net
+# Website: www.RahulVerma.net
 
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 
-  http://www.apache.org/licenses/LICENSE-2.0
+#   http://www.apache.org/licenses/LICENSE-2.0
 
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
-'''
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 import re
 import os
@@ -23,9 +21,10 @@ import os
 from enum import Enum, auto
 from abc import abstractmethod
 
-from arjuna.core.enums import GuiAutomationContext
-from arjuna.core.exceptions import GuiLabelNotPresentError
-from arjuna.interact.gui.auto.finder.emd import GuiElementMetaData
+from arjuna.tpi.enums import *
+from arjuna.core.enums import *
+from arjuna.tpi.exceptions import GuiLabelNotPresentError
+from arjuna.interact.gui.auto.finder.wmd import GuiWidgetMetaData
 from arjuna.interact.gui.auto.finder._with import ImplWith
 from arjuna.core.yaml import YamlFile
 
@@ -41,7 +40,7 @@ class GuiNamespaceLoaderFactory:
     # Returns GuiNamespaceLoader
     @classmethod
     def create_namespace_loader(cls, config, ns_file_path):
-        from arjuna.core.enums import ArjunaOption
+        from arjuna.tpi.enums import ArjunaOption
         multi_context_enabled = config.value(ArjunaOption.GUIAUTO_DEF_MULTICONTEXT)
         context = multi_context_enabled and None or config.guiauto_context
         _, file_extension = os.path.splitext(ns_file_path)
@@ -75,20 +74,20 @@ class GuiNamespace:
 
     def __init__(self, name):
         self.__name = name
-        # dict <string, dict<GuiAutomationContext, GuiElementMetaData>>
+        # dict <string, dict<GuiAutomationContext, GuiWidgetMetaData>>
         self.__ns = {}
 
     def is_empty(self):
         return not self.__ns
 
     def add_element_meta_data(self, name, context, raw_locators, meta):
-        emd = GuiElementMetaData.create_emd(*raw_locators, meta=meta)
+        wmd = GuiWidgetMetaData.create_wmd(*raw_locators, meta=meta)
         name = name.lower()
         if not self.has(name):
             self.__ns[name] = {}
-        self.__ns[name][context] = emd
+        self.__ns[name][context] = wmd
         from arjuna import Arjuna
-        Arjuna.get_logger().debug("Loaded {} label. EMD: {}".format(name, str(emd)))
+        Arjuna.get_logger().debug("Loaded {} label. EMD: {}".format(name, str(wmd)))
 
     def add_reference(self, name, value):
         self.__ns[name] = value
@@ -102,7 +101,7 @@ class GuiNamespace:
         return False
 
     # Needs to be thread-safe
-    # Returns emd for a context for a given gui name
+    # Returns wmd for a context for a given gui name
     def get_meta_data(self, label, context):
         msg = ""
         if self.is_empty():
@@ -206,7 +205,7 @@ class YamlGnsLoader(BaseGuiNamespaceLoader):
         common_withx = Arjuna.get_withx_ref()
 
         for label, label_map in yaml.get_section("labels").as_map().items():
-            Validator.arjuna_name(label)
+            Validator.name(label)
             self.__ns[label.lower()] = {"locators" : {self.__context: []}, "meta": dict()}
             for loc, loc_obj in label_map.items():
                 loc = loc.lower()
@@ -250,12 +249,12 @@ class YamlGnsLoader(BaseGuiNamespaceLoader):
             self.__ns["__root__"] = None
             self.__ns["__anchor__"] = None
 
-        for ename, emd in self.__ns.items():
+        for ename, wmd in self.__ns.items():
             if ename not in {'__root__', '__anchor__'}:
-                context_data = emd["locators"]
+                context_data = wmd["locators"]
                 for context, locators in context_data.items():
-                    self.add_element_meta_data(ename, context, locators, emd["meta"])
-                    Arjuna.get_logger().debug("Loading {} label for {} context with locators: {} and meta {}.".format(ename, context, [str(l) for l in locators], emd["meta"]))
+                    self.add_element_meta_data(ename, context, locators, wmd["meta"])
+                    Arjuna.get_logger().debug("Loading {} label for {} context with locators: {} and meta {}.".format(ename, context, [str(l) for l in locators], wmd["meta"]))
         
         self.add_reference("__root__", self.__ns["__root__"])
         self.add_reference("__anchor__", self.__ns["__anchor__"])
