@@ -1,21 +1,19 @@
-'''
-This file is a part of Arjuna
-Copyright 2015-2020 Rahul Verma
+# This file is a part of Arjuna
+# Copyright 2015-2020 Rahul Verma
 
-Website: www.RahulVerma.net
+# Website: www.RahulVerma.net
 
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 
-  http://www.apache.org/licenses/LICENSE-2.0
+#   http://www.apache.org/licenses/LICENSE-2.0
 
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
-'''
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 import argparse
 import copy
@@ -24,7 +22,7 @@ import sys
 import time
 
 from arjuna.core.utils import sys_utils
-from arjuna.core.enums import *
+from arjuna.tpi.enums import *
 from arjuna.core.enums import *
 from arjuna.core.reader.textfile import TextResourceReader
 from arjuna.core.types import constants
@@ -49,16 +47,17 @@ class ArjunaCLI:
         new_project_parser = NewProjectParser()
         project_parser = ProjectParser()
         run_parser = RunParser()
-        # session_parser = SessionParser()
+        run_default_group_parser = RunDefaultGroupParser()
+        session_parser = SessionParser()
         # group_parser = GroupParser()
         pickers_parser = PickersParser()
 
         # Create primary command handlers
         self.create_project = CreateProject(subparsers, [new_project_parser])
-        self.run_project = RunProject(subparsers, [project_parser, run_parser])
-        # self.run_session = RunSession(subparsers, [project_parser, run_parser, session_parser])
+        self.run_project = RunProject(subparsers, [project_parser, run_parser, run_default_group_parser])
+        self.run_session = RunSession(subparsers, [project_parser, run_parser, session_parser])
         # self.run_group = RunGroup(subparsers, [project_parser, run_parser, group_parser])
-        self.run_selected = RunSelected(subparsers, [project_parser, run_parser, pickers_parser])
+        self.run_selected = RunSelected(subparsers, [project_parser, run_parser, run_default_group_parser, pickers_parser])
 
     def init(self):
         time.sleep(0.1)
@@ -80,7 +79,7 @@ class ArjunaCLI:
             # CommandEnum.LAUNCH_SETU: "Launching Setu",
             CommandEnum.CREATE_PROJECT: "Creating new project",
             CommandEnum.RUN_PROJECT: "Running the project",
-            # CommandEnum.RUN_SESSION: "Running the selected session",
+            CommandEnum.RUN_SESSION: "Running the selected session",
             # CommandEnum.RUN_GROUP: "Running the selected group",
             CommandEnum.RUN_SELECTED: "Running tests based on selectors"
         }
@@ -97,7 +96,7 @@ class ArjunaCLI:
             # CommandEnum.LAUNCH_SETU: (self.launch_setu.execute,),
             CommandEnum.CREATE_PROJECT: (self.create_project.execute, ),
             CommandEnum.RUN_PROJECT: (self.run_project.execute, ),
-            # CommandEnum.RUN_SESSION: (self.run_session.execute, ),
+            CommandEnum.RUN_SESSION: (self.run_session.execute, ),
             # CommandEnum.RUN_GROUP: (self.run_group.execute, ),
             CommandEnum.RUN_SELECTED: (self.run_selected.execute, )
         }
