@@ -1,21 +1,19 @@
-'''
-This file is a part of Arjuna
-Copyright 2015-2020 Rahul Verma
+# This file is a part of Arjuna
+# Copyright 2015-2020 Rahul Verma
 
-Website: www.RahulVerma.net
+# Website: www.RahulVerma.net
 
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 
-  http://www.apache.org/licenses/LICENSE-2.0
+#   http://www.apache.org/licenses/LICENSE-2.0
 
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
-'''
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 import abc
 import os
@@ -28,6 +26,7 @@ import traceback
 import json
 import sys
 
+from arjuna.tpi.enums import *
 from arjuna.core.enums import *
 from arjuna.core.utils import sys_utils
 from arjuna.core.utils import file_utils
@@ -128,6 +127,7 @@ class CreateProject(Command):
     COMMON_DIRS_FILES = (
         (FileObjectType.DIR, "config"),
         (FileObjectType.DIR, "config/env"),
+        (FileObjectType.DIR, "config/run"),
         (FileObjectType.FILE, "config/project.conf"),
         (FileObjectType.DIR, "data"),
         (FileObjectType.DIR, "data/source"),
@@ -206,7 +206,7 @@ class CreateProject(Command):
             f = open(get_proj_target_path("test/conftest.py"), "w")
             f.write(contents)
             f.close()
-            for d in [ "config/env", "data/source", "l10n/excel", "l10n/json", "data/reference/excel_row", "data/reference/excel_column", "guiauto/namespace"]:
+            for d in [ "config/env", "config/run", "data/source", "l10n/excel", "l10n/json", "data/reference/excel_row", "data/reference/excel_column", "guiauto/namespace"]:
                 copy_file("../../res/placeholder.txt", d + "/placeholder.txt")
             for os_name in ["mac", "windows", "linux"]:
                 copy_file("../../res/placeholder.txt", "guiauto/driver/{}/placeholder.txt".format(os_name))
@@ -237,9 +237,12 @@ class __RunCommand(Command):
         runid = arg_dict.pop("run.id")
         static_rid = arg_dict.pop("static.rid")
         self.dry_run = arg_dict.pop("dry_run")
-        self.run_conf = arg_dict.pop("run_conf")
+        if "group.conf.name" in arg_dict:
+            self.group_conf_name = arg_dict.pop("group.conf.name")
+        else:
+            self.group_conf_name = None
 
-        Arjuna.init(project_root_dir, CliArgsConfig(arg_dict).as_map(), runid, static_rid=static_rid, run_conf=self.run_conf)
+        Arjuna.init(project_root_dir, CliArgsConfig(arg_dict).as_map(), runid, static_rid=static_rid)
 
         import sys
         proj_dir = Arjuna.get_config().value(ArjunaOption.PROJECT_ROOT_DIR)
@@ -251,19 +254,30 @@ class __RunCommand(Command):
 
 class RunProject(__RunCommand):
     def __init__(self, subparsers, parents):
-        super().__init__(subparsers, 'run-project', parents, "Run all tests in an Arjuna Test Project.")
+        super().__init__(subparsers, 'run-project', parents, "Run all tests in an Arjuna Test Project in a single thread.")
 
     def execute(self, arg_dict):
         super().execute(arg_dict)
-        from arjuna.engine.runner import TestRunner
-        test_runner = TestRunner()
-        test_runner.load_all_tests()
-        test_runner.run(dry_run=self.dry_run)
+        from arjuna import Arjuna
+        session = Arjuna.get_test_session()
+        session.load_tests(dry_run=self.dry_run, group_conf_name=self.group_conf_name)
+        session.run()
+
+class RunSession(__RunCommand):
+    def __init__(self, subparsers, parents):
+        super().__init__(subparsers, 'run-session', parents, "Run tests as per the session configuration file.")
+
+    def execute(self, arg_dict):
+        super().execute(arg_dict)
+        from arjuna import Arjuna
+        session = Arjuna.get_test_session()
+        session.load_tests(dry_run=self.dry_run, group_conf_name=self.group_conf_name)
+        session.run()
 
 class RunSelected(__RunCommand):
 
     def __init__(self, subparsers, parents):
-        super().__init__(subparsers, 'run-selected', parents, "Run tests selected based on selectors specified.")
+        super().__init__(subparsers, 'run-selected', parents, "Run tests selected based on selectors specified in a single thread.")
 
     def execute(self, arg_dict):
         pickers_dict = dict()
@@ -300,8 +314,8 @@ class RunSelected(__RunCommand):
 
         super().execute(arg_dict)
 
-        from arjuna.engine.runner import TestRunner
-        test_runner = TestRunner()
-        test_runner.load_tests_from_pickers(**pickers_dict)
-        test_runner.run(dry_run=self.dry_run)
+        from arjuna import Arjuna
+        session = Arjuna.get_test_session()
+        session.load_tests(**pickers_dict, dry_run=self.dry_run, group_conf_name=self.group_conf_name)
+        session.run()
 
