@@ -1,26 +1,25 @@
-'''
-This file is a part of Arjuna
-Copyright 2015-2020 Rahul Verma
+# This file is a part of Arjuna
+# Copyright 2015-2020 Rahul Verma
 
-Website: www.RahulVerma.net
+# Website: www.RahulVerma.net
 
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 
-  http://www.apache.org/licenses/LICENSE-2.0
+#   http://www.apache.org/licenses/LICENSE-2.0
 
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
-'''
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 import sys
 import re
 
-from arjuna.core.enums import ArjunaOption, ReportFormat
+from arjuna.tpi.enums import *
+from arjuna.core.enums import *
 
 def ustr(input):
     return (str(input)).upper()
@@ -85,3 +84,23 @@ def report_format(input):
         print('Exiting...', file=sys.stderr)
         sys.exit(1)
 
+def dry_run_type(input):
+    try:
+        return DryRunType[input.upper()]
+    except Exception as e:
+        allowed = ", ".join([e.name for e in DryRunType])
+        print('Invalid Dry Run Type provided: {}. Allowed values: {}'.format(input, allowed))
+        print('Exiting...', file=sys.stderr)
+        sys.exit(1)
+
+def int_or_notset(input):
+    try:
+        return int(input)
+    except:
+        if input.lower() == "not_set":
+            return "not_set"
+        else:
+            print(e)
+            print('Invalid input argument: {}. Expected an int.'.format(input))
+            print('Exiting...', file=sys.stderr)
+            sys.exit(1)
